package com.ruoyi.project.check.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.project.check.mapper.TCheckLawitemsMapper;
import com.ruoyi.project.check.domain.TCheckLawitems;
import com.ruoyi.project.check.service.ITCheckLawitemsService;

/**
 * 法规项Service业务层处理
 *
 * @author ruoyi
 * @date 2022-11-28
 */
@Service
public class TCheckLawitemsServiceImpl implements ITCheckLawitemsService
{
    @Autowired
    private TCheckLawitemsMapper tCheckLawitemsMapper;

    /**
     * 查询法规项
     *
     * @param id 法规项主键
     * @return 法规项
     */
    @Override
    public TCheckLawitems selectTCheckLawitemsById(Long id)
    {
        return tCheckLawitemsMapper.selectTCheckLawitemsById(id);
    }
    @Override
    public List<TCheckLawitems> selectTCheckLawitemsByLawStatus()
    {
        return tCheckLawitemsMapper.selectTCheckLawitemsByLawStatus();
    }

    /**
     * 查询法规项列表
     *
     * @param tCheckLawitems 法规项
     * @return 法规项
     */
    @Override
    public List<TCheckLawitems> selectTCheckLawitemsList(TCheckLawitems tCheckLawitems)
    {
        return tCheckLawitemsMapper.selectTCheckLawitemsList(tCheckLawitems);
    }

    /**
     * 新增法规项
     *
     * @param tCheckLawitems 法规项
     * @return 结果
     */
    @Override
    public int insertTCheckLawitems(TCheckLawitems tCheckLawitems)
    {
        return tCheckLawitemsMapper.insertTCheckLawitems(tCheckLawitems);
    }

    /**
     * 新增法规项
     *
     * @param tCheckLawitems 法规项列表
     * @return 结果
     */
    @Override
    public int insertTCheckLawitemsByList(List<TCheckLawitems> tCheckLawitems)
    {
        return tCheckLawitemsMapper.insertTCheckLawitemsByList(tCheckLawitems);
    }

    /**
     * 修改法规项
     *
     * @param tCheckLawitems 法规项
     * @return 结果
     */
    @Override
    public int updateTCheckLawitems(TCheckLawitems tCheckLawitems)
    {
        return tCheckLawitemsMapper.updateTCheckLawitems(tCheckLawitems);
    }

    /**
     * 批量删除法规项
     *
     * @param ids 需要删除的法规项主键
     * @return 结果
     */
    @Override
    public int deleteTCheckLawitemsByIds(Long[] ids)
    {
        return tCheckLawitemsMapper.deleteTCheckLawitemsByIds(ids);
    }

    /**
     * 删除法规项信息
     *
     * @param id 法规项主键
     * @return 结果
     */
    @Override
    public int deleteTCheckLawitemsById(Long id)
    {
        return tCheckLawitemsMapper.deleteTCheckLawitemsById(id);
    }
}
